@@ -45,24 +45,18 @@ __all__ = ['GtkView']
 
 class GtkViewArea(gtk.DrawingArea):
     """Custom widget to render an OpenGL scene"""
-    # The view this widget is rendering
-    view = None
-
-    # Pixmaps to use for double buffering
-    pixmap = None
-    dynamicPixmap = None
-    
-    # Flag to show if this scene is to be rendered using OpenGL
-    renderGL = False
-    
-    # TODO...
-    __glDrawable = None
     
     def __init__(self, view):
         """
         """
         gtk.DrawingArea.__init__(self)
-        
+
+        # Pixmaps to use for double buffering
+        self.pixmap = None
+        self.dynamicPixmap = None
+
+        self.renderGL = False # Flag to show if this scene is to be rendered using OpenGL
+        self.__glDrawable = None
         self.view = view
 
         # Allow notification of button presses
@@ -198,10 +192,12 @@ class GtkViewArea(gtk.DrawingArea):
             # Draw the window
             widget.window.draw_drawable(widget.get_style().white_gc, self.dynamicPixmap,
                                         event.area.x, event.area.y,
-                                        event.area.x, event.area.y, event.area.width, event.area.height)
+                                        event.area.x, event.area.y, event.area.width, event.area.height)   
 
     def __button_press(self, widget, event):
         """Gtk+ signal"""
+        if event.button != 1:
+            return
         self.__startGL()
         if self.view.feedback is not None:
             self.view.feedback.select(event.x, event.y)
@@ -209,6 +205,8 @@ class GtkViewArea(gtk.DrawingArea):
         
     def __button_release(self, widget, event):
         """Gtk+ signal"""
+        if event.button != 1:
+            return
         self.__startGL()
         if self.view.feedback is not None:
             self.view.feedback.deselect(event.x, event.y)
@@ -217,6 +215,7 @@ class GtkViewArea(gtk.DrawingArea):
 class GtkView(glchess.ui.ViewController):
     """
     """
+
     def __init__(self, ui, feedback, moveFormat = 'human', showComments = False):
         """Constructor for a view.
         
@@ -238,14 +237,14 @@ class GtkView(glchess.ui.ViewController):
         self.needsSaving = False
         
         # The GTK+ elements
-        self.gui = gtkui.loadGladeFile('chess_view.glade', 'chess_view')
-        self.gui.signal_autoconnect(self)
-        self.widget = self.gui.get_widget('chess_view')
+        self.gui = gtkui.loadUIFile('chess_view.ui', 'chess_view')
+        self.gui.connect_signals(self)
+        self.widget = self.gui.get_object('chess_view')
 
         self.viewWidget = GtkViewArea(self)
-        self.gui.get_widget('view_container').add(self.viewWidget)
+        self.gui.get_object('view_container').add(self.viewWidget)
 
-        self.ui.setTooltipStyle(self.gui.get_widget('info_panel'))
+        self.ui.setTooltipStyle(self.gui.get_object('info_panel'))
 
         # Make a model for navigation (move object, number, description) 
         model = gtk.ListStore(gobject.TYPE_PYOBJECT, int, str)
@@ -255,7 +254,7 @@ class GtkView(glchess.ui.ViewController):
         self.moveModel = model
 
         # Tabs are enabled to make editing the UI easier
-        self.gui.get_widget('comment_notebook').set_show_tabs(False)
+        self.gui.get_object('comment_notebook').set_show_tabs(False)
         
         self.updateInfoPanel()
 
@@ -269,9 +268,9 @@ class GtkView(glchess.ui.ViewController):
         """
         showPanel = False
         
-        panel = self.gui.get_widget('info_panel')
-        titleLabel = self.gui.get_widget('panel_title_label')
-        descriptionLabel = self.gui.get_widget('panel_description_label')
+        panel = self.gui.get_object('info_panel')
+        titleLabel = self.gui.get_object('panel_title_label')
+        descriptionLabel = self.gui.get_object('panel_description_label')
         
         move = self._getCurrentMove()
         if self.gameResult is not None:
@@ -280,7 +279,7 @@ class GtkView(glchess.ui.ViewController):
             descriptionLabel.set_markup('<i>%s</i>' % description)
             showPanel = True
 
-        editToggle = self.gui.get_widget('comment_edit_toggle')
+        editToggle = self.gui.get_object('comment_edit_toggle')
         if self.showComments:
             # Show the comments
             if move is None:
@@ -570,6 +569,13 @@ class GtkView(glchess.ui.ViewController):
             
             self.ui._updateViewButtons()
 
+    def undoMove(self):
+        """Extends glchess.ui.ViewController"""
+        iter = self.moveModel.iter_nth_child(None, len(self.moveModel) - 1)
+        self.moveModel.remove(iter)
+        self.selectedMove = -1
+        self.ui._updateViewButtons()        
+
     def endGame(self, game):
         # Translators: Message displayed when a player wins. The %s is substituted with the winning player's name
         format = _('%s wins')
@@ -598,7 +604,7 @@ class GtkView(glchess.ui.ViewController):
             description = _('Opponent has run out of time')
         elif game.rule is glchess.game.RULE_THREE_FOLD_REPETITION:
             # Translators: Message displayed when the game is drawn due to the three-fold-repitition rule
-            description = _('The same board state has occured three times (three fold repetition)')
+            description = _('The same board state has occurred three times (three fold repetition)')
         elif game.rule is glchess.game.RULE_INSUFFICIENT_MATERIAL:
             # Translators: Message displayed when the game is drawn due to the insufficient material rule
             description = _('Neither player can cause checkmate (insufficient material)')
@@ -611,6 +617,9 @@ class GtkView(glchess.ui.ViewController):
                 description = _('The white player has resigned')
             else:
                 assert(False)
+        elif game.rule is glchess.game.RULE_ABANDONMENT:
+            # Translators: Message displayed when a game is abandoned
+            description = _('The game has been abandoned')                
         elif game.rule is glchess.game.RULE_DEATH:
             # Translators: Message displayed when the game ends due to a player dying
             description = _('One of the players has died')
@@ -653,8 +662,8 @@ class GtkView(glchess.ui.ViewController):
     
     def _on_comment_edit_button_toggled(self, widget):
         """Gtk+ callback"""
-        label = self.gui.get_widget('panel_description_label')
-        entry = self.gui.get_widget('comment_text')
+        label = self.gui.get_object('panel_description_label')
+        entry = self.gui.get_object('comment_text')
         buffer = entry.get_buffer()
         
         move = self._getCurrentMove()
@@ -678,4 +687,4 @@ class GtkView(glchess.ui.ViewController):
             label.set_text(comment)
             buffer.set_text('')
             page = 0
-        self.gui.get_widget('comment_notebook').set_current_page(page)
+        self.gui.get_object('comment_notebook').set_current_page(page)
