@@ -24,12 +24,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
 #include <strings.h>		/* For strcasecmp */
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "games-dlg-players.h"
@@ -108,11 +109,11 @@ update_player_list (GtkWidget * tree)
     GGZSeat seat = ggzmod_get_seat (ggz, p);
     GtkTreeIter iter;
     const gchar *status = NULL, *name = NULL;
-    gchar num[32];
+    gchar numstr[32];
 
     gtk_list_store_append (store, &iter);
 
-    snprintf (num, sizeof (num), "%d", p);
+    snprintf (numstr, sizeof (numstr), "%d", p);
     switch (seat.type) {
     case GGZ_SEAT_PLAYER:
       status = _("Occupied");
@@ -138,10 +139,12 @@ update_player_list (GtkWidget * tree)
       status = _("-");
       name = seat.name;
       break;
+    default:
+      g_assert_not_reached ();
     }
 
     gtk_list_store_set (store, &iter,
-			PLAYER_COLUMN_SEAT, num,
+			PLAYER_COLUMN_SEAT, numstr,
 			PLAYER_COLUMN_ISSPECTATOR,
 			(gboolean) FALSE, PLAYER_COLUMN_SEATNUM,
 			(gint) p, PLAYER_COLUMN_TYPE, status,
@@ -190,7 +193,7 @@ create_player_list (void)
   GtkWidget *tree;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkTreeSelection *select;
+  GtkTreeSelection *selection;
 
   assert (PLAYER_COLUMNS == 5);
   store = gtk_list_store_new (PLAYER_COLUMNS,
@@ -223,12 +226,12 @@ create_player_list (void)
 					      PLAYER_COLUMN_NAME, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
 
-  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
-  gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
   /* FIXME:  This feature is not supported by gnome-games yet. 
    * g_signal_connect(tree, "button-press-event",
-   * GTK_SIGNAL_FUNC(player_list_button_event), NULL);
+   * G_CALLBACK(player_list_button_event), NULL);
    */
   update_player_list (tree);
 
@@ -244,7 +247,7 @@ create_playerlist_widget (void)
   player_lists = list;
 
   g_signal_connect (list->this, "destroy",
-		    GTK_SIGNAL_FUNC (gtk_widget_destroyed), &list->this);
+		    G_CALLBACK (gtk_widget_destroyed), &list->this);
 
   return list->this;
 }
@@ -274,17 +277,10 @@ create_dlg_players (GtkWindow * parent)
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
   gtk_widget_show (vbox);
 
-#if 0
-  label = gtk_label_new (_("List of players:"));
-  gtk_widget_ref (label);
-  gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-#endif
-
   tree = create_player_list ();
-  gtk_widget_ref (tree);
+  g_object_ref_sink(tree);
   g_object_set_data_full (G_OBJECT (dialog), "tree", tree,
-			  (GtkDestroyNotify) gtk_widget_unref);
+			  (GDestroyNotify) g_object_unref);
   gtk_box_pack_start (GTK_BOX (vbox), tree, FALSE, FALSE, 0);
   gtk_widget_show (tree);
 
@@ -292,9 +288,9 @@ create_dlg_players (GtkWindow * parent)
    * Set up callbacks
    */
   g_signal_connect (dialog, "delete_event",
-		    GTK_SIGNAL_FUNC (gtk_widget_destroy), NULL);
+		    G_CALLBACK (gtk_widget_destroy), NULL);
   g_signal_connect (dialog, "response",
-		    GTK_SIGNAL_FUNC (gtk_widget_destroy), NULL);
+		    G_CALLBACK (gtk_widget_destroy), NULL);
 
   /* 
    * Done!
@@ -311,7 +307,7 @@ create_or_raise_dlg_players (GtkWindow * window)
   } else {
     dlg_players = create_dlg_players (window);
     g_signal_connect (dlg_players, "destroy",
-		      GTK_SIGNAL_FUNC (gtk_widget_destroyed), &dlg_players);
+		      G_CALLBACK (gtk_widget_destroyed), &dlg_players);
     gtk_widget_show (dlg_players);
   }
 }
@@ -417,13 +413,13 @@ popup_player_menu (GGZSeat * seat, GGZSpectatorSeat * sseat, guint button)
 
     /* FIXME: what about bot/reservation seats? */
     info = gtk_menu_item_new_with_label (_("Info"));
-    gtk_widget_ref (info);
-    g_object_set_data_full (G_OBJECT (menu), "info", info, (GtkDestroyNotify)
-			    gtk_widget_unref);
+    g_object_ref_sink(info);
+    g_object_set_data_full (G_OBJECT (menu), "info", info, (GDestroyNotify)
+			    g_object_unref);
     gtk_container_add (GTK_CONTAINER (menu), info);
     gtk_widget_set_sensitive (info, FALSE);
     g_signal_connect (info, "activate",
-		      GTK_SIGNAL_FUNC (player_info_activate), which);
+		      G_CALLBACK (player_info_activate), which);
   }
 
   if ((sseat && strcasecmp (sseat->name, my_name))
@@ -433,13 +429,13 @@ popup_player_menu (GGZSeat * seat, GGZSpectatorSeat * sseat, guint button)
 
     /* FIXME: you shouldn't be able to boot yourself */
     boot = gtk_menu_item_new_with_label (_("Boot player"));
-    gtk_widget_ref (boot);
-    g_object_set_data_full (G_OBJECT (menu), "boot", boot, (GtkDestroyNotify)
-			    gtk_widget_unref);
+    g_object_ref_sink(boot);
+    g_object_set_data_full (G_OBJECT (menu), "boot", boot, (GDestroyNotify)
+			    g_object_unref);
     gtk_container_add (GTK_CONTAINER (menu), boot);
     // gtk_widget_set_sensitive(boot, FALSE);
     g_signal_connect (boot, "activate",
-		      GTK_SIGNAL_FUNC (player_boot_activate), which);
+		      G_CALLBACK (player_boot_activate), which);
   }
 
   if (seat
@@ -455,13 +451,13 @@ popup_player_menu (GGZSeat * seat, GGZSpectatorSeat * sseat, guint button)
       label = _("Move here");
 
     sit = gtk_menu_item_new_with_label (label);
-    gtk_widget_ref (sit);
-    g_object_set_data_full (G_OBJECT (menu), "sit", sit, (GtkDestroyNotify)
-			    gtk_widget_unref);
+    g_object_ref_sink(sit);
+    g_object_set_data_full (G_OBJECT (menu), "sit", sit, (GDestroyNotify)
+			    g_object_unref);
     gtk_container_add (GTK_CONTAINER (menu), sit);
     // gtk_widget_set_sensitive(sit, FALSE);
     g_signal_connect (sit, "activate",
-		      GTK_SIGNAL_FUNC (player_sit_activate), which);
+		      G_CALLBACK (player_sit_activate), which);
   }
 
   if (seat && (seat->type == GGZ_SEAT_OPEN
@@ -469,12 +465,12 @@ popup_player_menu (GGZSeat * seat, GGZSpectatorSeat * sseat, guint button)
     GtkWidget *bot;
 
     bot = gtk_menu_item_new_with_label (_("Play with bot"));
-    gtk_widget_ref (bot);
-    g_object_set_data_full (G_OBJECT (menu), "bot", bot, (GtkDestroyNotify)
-			    gtk_widget_unref);
+    g_object_ref_sink(bot);
+    g_object_set_data_full (G_OBJECT (menu), "bot", bot, (GDestroyNotify)
+			    g_object_unref);
     gtk_container_add (GTK_CONTAINER (menu), bot);
     g_signal_connect (bot, "activate",
-		      GTK_SIGNAL_FUNC (player_bot_activate), which);
+		      G_CALLBACK (player_bot_activate), which);
   }
 
   if (seat && (seat->type == GGZ_SEAT_BOT || seat->type == GGZ_SEAT_RESERVED)) {
@@ -487,12 +483,12 @@ popup_player_menu (GGZSeat * seat, GGZSpectatorSeat * sseat, guint button)
       label = _("Remove bot");
 
     open = gtk_menu_item_new_with_label (label);
-    gtk_widget_ref (open);
-    g_object_set_data_full (G_OBJECT (menu), "open", open, (GtkDestroyNotify)
-			    gtk_widget_unref);
+    g_object_ref_sink (open);
+    g_object_set_data_full (G_OBJECT (menu), "open", open, (GDestroyNotify)
+			    g_object_unref);
     gtk_container_add (GTK_CONTAINER (menu), open);
     g_signal_connect (open, "activate",
-		      GTK_SIGNAL_FUNC (player_open_activate), which);
+		      G_CALLBACK (player_open_activate), which);
   }
 
   gtk_widget_show_all (menu);
